@@ -31,18 +31,27 @@ class Execution(base.Resource):
 class ExecutionManager(base.ResourceManager):
     resource_class = Execution
 
-    def create(self, workflow_identifier, workflow_input=None, description='',
+    def create(self, workflow_identifier='', namespace='',
+               workflow_input=None, description='', source_execution_id=None,
                **params):
-        self._ensure_not_empty(workflow_identifier=workflow_identifier)
+        ident = workflow_identifier or source_execution_id
+        self._ensure_not_empty(workflow_identifier=ident)
 
         data = {
-            'description': description
+            'description': description,
         }
 
-        if uuidutils.is_uuid_like(workflow_identifier):
-            data.update({'workflow_id': workflow_identifier})
-        else:
-            data.update({'workflow_name': workflow_identifier})
+        if uuidutils.is_uuid_like(source_execution_id):
+            data.update({'source_execution_id': source_execution_id})
+
+        if workflow_identifier:
+            if uuidutils.is_uuid_like(workflow_identifier):
+                data.update({'workflow_id': workflow_identifier})
+            else:
+                data.update({'workflow_name': workflow_identifier})
+
+        if namespace:
+            data.update({'workflow_namespace': namespace})
 
         if workflow_input:
             if isinstance(workflow_input, six.string_types):
@@ -69,13 +78,17 @@ class ExecutionManager(base.ResourceManager):
 
         return self._update('/executions/%s' % id, data)
 
-    def list(self, marker='', limit=None, sort_keys='', sort_dirs=''):
+    def list(self, task=None, marker='', limit=None, sort_keys='',
+             sort_dirs='', **filters):
         qparams = {}
 
+        if task:
+            qparams['task_execution_id'] = task
+
         if marker:
             qparams['marker'] = marker
 
-        if limit:
+        if limit and limit > 0:
             qparams['limit'] = limit
 
         if sort_keys:
@@ -84,6 +97,9 @@ class ExecutionManager(base.ResourceManager):
         if sort_dirs:
             qparams['sort_dirs'] = sort_dirs
 
+        for name, val in filters.items():
+            qparams[name] = val
+
         query_string = ("?%s" % urlparse.urlencode(list(qparams.items()))
                         if qparams else "")
 
@@ -97,7 +113,14 @@ class ExecutionManager(base.ResourceManager):
 
         return self._get('/executions/%s' % id)
 
-    def delete(self, id):
+    def delete(self, id, force=None):
         self._ensure_not_empty(id=id)
+        qparams = {}
 
-        self._delete('/executions/%s' % id)
+        if force:
+            qparams['force'] = True
+
+        query_string = ("?%s" % urlparse.urlencode(list(qparams.items()))
+                        if qparams else "")
+
+        self._delete('/executions/%s%s' % (id, query_string))
